==> bigloo_1.9c.orig.tar.gz: bigloo1.9c/recette/print.scm <==
;* --------------------------------------------------------------------*/
;*    Copyright (c) 1992-1998 by Manuel Serrano. All rights reserved.  */
;*                                                                     */
;*                                     ,--^,                           */
;*                               _ ___/ /|/                            */
;*                           ,;'( )__, ) '                             */
;*                          ;;  //   L__.                              */
;*                          '   \   /  '                               */
;*                               ^   ^                                 */
;*                                                                     */
;*                                                                     */
;*    This program is distributed in the hope that it will be useful.  */
;*    Use and copying of this software and preparation of derivative   */
;*    works based upon this software are permitted, so long as the     */
;*    following conditions are met:                                    */
;*           o credit to the authors is acknowledged following         */
;*             current academic behaviour                              */
;*           o no fees or compensation are charged for use, copies,    */
;*             or access to this software                              */
;*           o this copyright notice is included intact.               */
;*      This software is made available AS IS, and no warranty is made */
;*      about the software or its performance.                         */
;*                                                                     */
;*      Bug descriptions, use reports, comments or suggestions are     */
;*      welcome. Send them to                                          */
;*        Manuel Serrano -- Manuel.Serrano@unice.fr                    */
;*-------------------------------------------------------------------- */
;*---------------------------------------------------------------------*/
;*    serrano/prgm/project/bigloos/recette/print.scm ...               */
;*                                                                     */
;*    Author      :  Manuel Serrano                                    */
;*    Creation    :  Tue Nov  3 09:47:58 1992                          */
;*    Last change :  Tue Nov  3 15:13:28 1992  (serrano)               */
;*                                                                     */
;*    On affiche des objects pour voir si tous ce passe bien           */
;*---------------------------------------------------------------------*/

;*---------------------------------------------------------------------*/
;*    Le module                                                        */
;*---------------------------------------------------------------------*/
(module print
   (import  (main "main.scm"))
   (include "test.sch")
   (export  (test-print)))

;*---------------------------------------------------------------------*/
;*    test-print ...                                                   */
;*---------------------------------------------------------------------*/
(define (test-print)
   (test-module "print" "print.scm" #f)
   (test "char" (begin (display #\Z *recette-port*) #t) #t)
   (test "string" (begin (display "toto n'est pas content" *recette-port*)
			 #t)
	 #t)
   (test "integer" (begin (display 1 *recette-port*) #t) #t)
   (test "integer" (begin (display -1 *recette-port*) #t) #t)
   (test "list" (begin (display '(1 2 3 4 5) *recette-port*) #t) #t)
   (test "vector" (begin (display '#(1 2 3 4 5) *recette-port*) #t) #t)
   (test "newline" (begin (fprint *recette-port* #\Newline) #t) #t))

==> bigloo_2.8c.orig.tar.gz: bigloo2.8c/recette/print.scm <==
;*---------------------------------------------------------------------*/
;*    serrano/prgm/project/bigloo/recette/print.scm                    */
;*                                                                     */
;*    Author      :  Manuel Serrano                                    */
;*    Creation    :  Tue Nov  3 09:47:58 1992                          */
;*    Last change :  Wed Apr  1 14:10:02 1998 (serrano)                */
;*                                                                     */
;*    On affiche des objects pour voir si tous ce passe bien           */
;*---------------------------------------------------------------------*/

;*---------------------------------------------------------------------*/
;*    Le module                                                        */
;*---------------------------------------------------------------------*/
(module print
   (import  (main "main.scm"))
   (include "test.sch")
   (export  (test-print)))

;*---------------------------------------------------------------------*/
;*    test-print ...                                                   */
;*---------------------------------------------------------------------*/
(define (test-print)
   (test-module "print" "print.scm")
   (test "char" (begin (display #\Z *recette-port*) #t) #t)
   (test "string" (begin (display "toto n'est pas content" *recette-port*)
			 #t)
	 #t)
   (test "integer" (begin (display 1 *recette-port*) #t) #t)
   (test "integer" (begin (display -1 *recette-port*) #t) #t)
   (test "list" (begin (display '(1 2 3 4 5) *recette-port*) #t) #t)
   (test "vector" (begin (display '#(1 2 3 4 5) *recette-port*) #t) #t)
   (test "newline" (begin (fprint *recette-port* #\Newline) #t) #t))
